unit Main;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  Menus, ComCtrls, ToolWin, StdCtrls, Child, PrintSM;

type
  TfrmMain = class(TForm)
    MainMenu: TMainMenu;
    miFile: TMenuItem;
    miFileOpen: TMenuItem;
    miFileSeparator2: TMenuItem;
    miFileExit: TMenuItem;
    miView: TMenuItem;
    miFileReportDescription: TMenuItem;
    miHelp: TMenuItem;
    miHelpAbout: TMenuItem;
    ImageList: TImageList;
    CoolBar: TCoolBar;
    cbReport: TComboBox;
    miViewSeparator: TMenuItem;
    miViewLanguage: TMenuItem;
    miViewLangEnglish: TMenuItem;
    miViewLangRussian: TMenuItem;
    miViewLangUkraine: TMenuItem;
    miViewLangGerman: TMenuItem;
    miViewLangFrench: TMenuItem;
    miViewLangSeparator: TMenuItem;
    miViewLangAutoDetect: TMenuItem;
    miViewCustomPreview: TMenuItem;
    miFileClose: TMenuItem;
    miFileCloseAll: TMenuItem;
    miFileSeparator1: TMenuItem;
    miWindow: TMenuItem;
    miWindowNext: TMenuItem;
    miWindowPrevious: TMenuItem;
    miWindowCascade: TMenuItem;
    miWindowTileH: TMenuItem;
    miWindowTileV: TMenuItem;
    miWindowArrange: TMenuItem;
    miWindowMinimizeAll: TMenuItem;
    StatusBar: TStatusBar;
    ToolBar: TToolBar;
    btnExit: TToolButton;
    btnClose: TToolButton;
    btnSeparator1: TToolButton;
    btnDesign: TToolButton;
    btnPreview: TToolButton;
    btnPrint: TToolButton;
    btnAutoRep: TToolButton;
    ToolBarDS: TToolBar;
    btnFirst: TToolButton;
    btnPrev: TToolButton;
    btnNext: TToolButton;
    btnLast: TToolButton;
    btnRepNote: TToolButton;
    miViewSMPrintData: TMenuItem;
    miBlankIfZero: TMenuItem;
    miWordWrap: TMenuItem;
    miWordWrapHeader: TMenuItem;
    miViewTwoPass: TMenuItem;
    miAutoFit: TMenuItem;
    miPrintRecNo: TMenuItem;
    miSelectedRecord: TMenuItem;
    miSeparator1: TMenuItem;
    miDataFromDBGrid: TMenuItem;
    miDataFromDataSet: TMenuItem;
    miSeparator2: TMenuItem;
    miPrintRecNo1: TMenuItem;
    miPrintRecNo2: TMenuItem;
    miPrintRecNo3: TMenuItem;
    miGridStyle: TMenuItem;
    miSeparator3: TMenuItem;
    miGridNormal: TMenuItem;
    miGridPriceList: TMenuItem;
    procedure FormCreate(Sender: TObject);
    procedure ReportOpen(Sender: TObject);
    procedure miFileCloseClick(Sender: TObject);
    procedure miFileCloseAllClick(Sender: TObject);
    procedure miWindowCascadeClick(Sender: TObject);
    procedure miWindowTileHClick(Sender: TObject);
    procedure miWindowArrangeClick(Sender: TObject);
    procedure miWindowMinimizeAllClick(Sender: TObject);
    procedure miWindowNextClick(Sender: TObject);
    procedure miWindowPreviousClick(Sender: TObject);
    procedure DSNavigateClick(Sender: TObject);
    procedure btnAutoRepClick(Sender: TObject);
    procedure miFileReportDescriptionClick(Sender: TObject);
    procedure miFileExitClick(Sender: TObject);
    procedure btnDesignClick(Sender: TObject);
    procedure btnPreviewClick(Sender: TObject);
    procedure btnPrintClick(Sender: TObject);
    procedure miViewLangFrenchClick(Sender: TObject);
    procedure miHelpAboutClick(Sender: TObject);
    procedure StatusBarDrawPanel(StatusBar: TStatusBar;
      Panel: TStatusPanel; const Rect: TRect);
    procedure StatusBarResize(Sender: TObject);
  private
    { Private declarations }
    procedure ShowNoActivate;
    procedure ShowMDIForm(FFormClass: TComponentClass; FormName: string);
    procedure DisplayHint(Sender: TObject);
    procedure SetLangAndPreview(rpt: TSMPrintBaseComponent);
    procedure CustomPreviewEvent(Sender: TObject);
  public
    { Public declarations }
  end;

var
  frmMain: TfrmMain;

implementation

uses SMDesign, RepNote, CustPrev, SMRAuto, SMRBase,
     SimpleLst, ColList, SimpleGrp, ManyGrp, SimplePic, MastDeta;

{$R *.DFM}
{$R winxp.res}

procedure TfrmMain.FormCreate(Sender: TObject);
var i: Integer;
    NewItem: TMenuItem;
begin
  for i := 0 to cbReport.Items.Count-1 do
  begin
    NewItem := TMenuItem.Create(Self);
    NewItem.Caption := cbReport.Items[i];
    NewItem.OnClick := ReportOpen;
    NewItem.RadioItem := True;
    NewItem.Tag := i;
    miFileOpen.Add(NewItem)
  end;

//  cbReport.ItemIndex := 0;
  Application.OnHint := DisplayHint;
end;

procedure TfrmMain.DisplayHint(Sender: TObject);
begin
  StatusBar.Panels[0].Text := Application.Hint
end;

procedure TfrmMain.ReportOpen(Sender: TObject);
var rpt: TSMPrintText;
    smrComposite: TSMRCompositeReport;
begin
  if Sender is TMenuItem then
    cbReport.ItemIndex := TMenuItem(Sender).Tag;

  case cbReport.ItemIndex of
    0: ShowMDIForm(TfrmSimpleList, 'frmSimpleList');
    1: ShowMDIForm(TfrmMultiColumnar, 'frmMultiColumnar');
    2: ShowMDIForm(TfrmSimpleGrp, 'frmSimpleGrp');
    3: ShowMDIForm(TfrmMasterDetail, 'frmMasterDetail');
    4: ShowMDIForm(TfrmManyGrp, 'frmManyGrp');
    5: ShowMDIForm(TfrmSimplePic, 'frmSimplePic');
    6: begin
         rpt := TSMPrintText.Create(Application);
         with rpt do
           try
             SetLangAndPreview(rpt);
             rpt.TwoPass := miViewTwoPass.Checked;
             SMProperty.Title := 'Autogenerated text report';
             Preview;
           finally
             Free
           end;
       end;
    7: begin
         smrComposite := TSMRCompositeReport.Create(Application);
         with smrComposite do
           try
             ClearReports;
             if (ActiveMDIChild <> nil) then
             begin
               SetLangAndPreview(smrComposite);
               with TfrmChildParent(ActiveMDIChild) do
               begin
                 AddReport(SMReport);
                 AddReport(SMPrintData);
               end;
               Preview;
             end;
           finally
             Free;
           end;
       end;
  end;
end;

procedure TfrmMain.ShowMDIForm(FFormClass: TComponentClass; FormName: string);
var frm: TForm;
    i: Integer;
begin
  Screen.Cursor := crHourglass;
  for i := 0 to MDIChildCount-1 do
    if MDIChildren[i].Name = FormName then
      break;
  if i < MDIChildCount then
    frm := MDIChildren[i]
  else
    Application.CreateForm(FFormClass, frm);
  frm.Show;
  Screen.Cursor := crDefault;
end;

procedure TfrmMain.miFileCloseClick(Sender: TObject);
begin
  if (ActiveMDIChild <> nil) then
    ActiveMDIChild.Close;
end;

procedure TfrmMain.miFileCloseAllClick(Sender: TObject);
var i: Integer;
begin
  for i := MDIChildCount - 1 downto 0 do
    MDIChildren[i].Close;
end;

procedure TfrmMain.miWindowCascadeClick(Sender: TObject);
begin
  Cascade
end;

procedure TfrmMain.miWindowTileHClick(Sender: TObject);
begin
  if (Sender = miWindowTileH) then
    TileMode := tbHorizontal
  else
    if (Sender = miWindowTileV) then
      TileMode := tbVertical;
  Tile;
end;

procedure TfrmMain.miWindowArrangeClick(Sender: TObject);
begin
  ArrangeIcons
end;

procedure TfrmMain.miWindowMinimizeAllClick(Sender: TObject);
var i: Integer;
begin
  for i := MDIChildCount - 1 downto 0 do
    MDIChildren[i].WindowState := wsMinimized;
end;

procedure TfrmMain.miWindowNextClick(Sender: TObject);
begin
  Next
end;

procedure TfrmMain.miWindowPreviousClick(Sender: TObject);
begin
  Previous
end;

procedure TfrmMain.DSNavigateClick(Sender: TObject);
begin
  if (Sender is TComponent) and
     (ActiveMDIChild <> nil) then
    with TfrmChildParent(ActiveMDIChild).DBGrid.DataSource.DataSet do
      case TComponent(Sender).Tag of
        1: Prior;
        2: Next;
        3: Last;
      else
        First;
      end;
end;

procedure TfrmMain.btnAutoRepClick(Sender: TObject);
begin
  if (ActiveMDIChild <> nil) then
    with TfrmChildParent(ActiveMDIChild) do
    begin
      SetLangAndPreview(SMPrintData);
      SMPrintData.TwoPass := miViewTwoPass.Checked;

      SMPrintData.AutoFit := miAutoFit.Checked;
      SMPrintData.BlankIfZero := miBlankIfZero.Checked;
      SMPrintData.WordWrap := miWordWrap.Checked;
      SMPrintData.WordWrapHeader := miWordWrapHeader.Checked;
      if miPrintRecNo1.Checked then
        SMPrintData.PrintRecNo := rnNone
      else
        if miPrintRecNo2.Checked then
          SMPrintData.PrintRecNo := rnFirstCol
        else
          SMPrintData.PrintRecNo := rnFirstColOnEachBar;
      SMPrintData.SelectedRecord := miSelectedRecord.Checked;
      if miDataFromDBGrid.Checked then
        SMPrintData.ColumnSource := csDBGrid
      else
        SMPrintData.ColumnSource := csDataSet;
      if miGridNormal.Checked then
        SMPrintData.Style.RowStyle := rsNormal
      else
        SMPrintData.Style.RowStyle := rsPriceList;

      SMPrintData.Preview;
    end
  else
    ShowNoActivate;
end;

procedure TfrmMain.SetLangAndPreview(rpt: TSMPrintBaseComponent);

  function GetLang: TSMRLangID;
  var i: Integer;
  begin
    Result := lnEnglish;

    for i := 0 to 4 do
      if miViewLanguage.Items[i].Checked then
      begin
        Result := TSMRLangID(i);
        break
      end;
  end;

begin
  rpt.Language.AutoDetect := miViewLangAutoDetect.Checked;
  rpt.Language.LanguageID := GetLang;
  if miViewCustomPreview.Checked then
    rpt.OnPreview := CustomPreviewEvent
  else
    rpt.OnPreview := nil;
end;

procedure TfrmMain.CustomPreviewEvent(Sender: TObject);
begin
  with TfrmCustomPreview.Create(Application) do
  try
    SMRPreview.Report := (Sender as TSMPrintBaseComponent);
    ShowModal
  finally
    Free
  end;
end;

procedure TfrmMain.miFileReportDescriptionClick(Sender: TObject);
begin
  if (Self.ActiveMDIChild <> nil) then
    with TfrmReportDescription.Create(Application) do
      try
        memoNote.Lines.Assign(TfrmChildParent(Self.ActiveMDIChild).SMReport.SMProperty.Comments);
        ShowModal
      finally
        Free
      end
  else
    ShowNoActivate;
end;

procedure TfrmMain.miFileExitClick(Sender: TObject);
begin
  Close
end;

procedure TfrmMain.ShowNoActivate;
begin
  ShowMessage('Before this mode using you must select the report example from combobox.')
end;

procedure TfrmMain.btnDesignClick(Sender: TObject);
begin
  if (ActiveMDIChild <> nil) then
    with TfrmChildParent(ActiveMDIChild) do
    begin
      SetLangAndPreview(SMReport);
      SMReport.TwoPass := miViewTwoPass.Checked;
      DesignReport(SMReport);
    end
  else
    ShowNoActivate;
end;

procedure TfrmMain.btnPreviewClick(Sender: TObject);
begin
  if (ActiveMDIChild <> nil) then
    with TfrmChildParent(ActiveMDIChild) do
    begin
      SetLangAndPreview(SMReport);
      SMReport.TwoPass := miViewTwoPass.Checked;
      SMReport.Preview;
    end
  else
    ShowNoActivate;
end;

procedure TfrmMain.btnPrintClick(Sender: TObject);
begin
  if (ActiveMDIChild <> nil) then
    with TfrmChildParent(ActiveMDIChild) do
    begin
      SetLangAndPreview(SMReport);
      SMReport.TwoPass := miViewTwoPass.Checked;
      SMReport.Print;
    end
  else
    ShowNoActivate;
end;

procedure TfrmMain.miViewLangFrenchClick(Sender: TObject);
begin
  with Sender as TMenuItem do
    Checked := not Checked;
end;

procedure TfrmMain.miHelpAboutClick(Sender: TObject);
begin
  if (ActiveMDIChild <> nil) then
    with TfrmChildParent(ActiveMDIChild) do
    begin
      SetLangAndPreview(SMReport);
      SMReport.About;
    end;
end;

procedure TfrmMain.StatusBarDrawPanel(StatusBar: TStatusBar;
  Panel: TStatusPanel; const Rect: TRect);
begin
  with StatusBar.Canvas do
  begin
    Brush.Style := bsClear;
    Font.Name := 'Arial';
    Font.Style := [fsBold, fsItalic];
    Font.Color := clWhite;
    TextOut(Rect.Left + 2, Rect.Top, Panel.Text);

    Font.Color := clGreen;
    TextOut(Rect.Left + 1, Rect.Top + 1, Panel.Text);
  end;
end;

procedure TfrmMain.StatusBarResize(Sender: TObject);
begin
  StatusBar.Panels[0].Width := StatusBar.Width -
                               StatusBar.Panels[1].Width - 10;
end;

end.
